@@ -18,7 +18,7 @@ volatile sig_atomic_t gotsig;
 static const char hfile[] = ".whistory";
 
 static wchar_t *
-prompt(EditLine __attribute__((unused)) *el)
+prompt(EditLine *el)
 {
 	static wchar_t a[] = L"\1\033[7m\1Edit$\1\033[0m\1 ";
 	static wchar_t b[] = L"Edit> ";
@@ -54,15 +54,14 @@ my_wcstombs(const wchar_t *wstr)
 
 
 static unsigned char
-complete(EditLine *el, int __attribute__((unused)) ch)
+complete(EditLine *el, int ch)
 {
 	DIR *dd = opendir(".");
 	struct dirent *dp;
 	const wchar_t *ptr;
 	char *buf, *bptr;
 	const LineInfoW *lf = el_wline(el);
-	int len, i;
-	size_t mblen;
+	int len, mblen, i;
 	unsigned char res = 0;
 	wchar_t dir[1024];
 
@@ -75,10 +74,9 @@ complete(EditLine *el, int __attribute__((unused)) ch)
 	wctomb(NULL, 0); /* Reset shift state */
 	mblen = MB_LEN_MAX * len + 1;
 	buf = bptr = malloc(mblen);
-	if (buf == NULL) {
+	if (buf == NULL)
 		fprintf(stderr, "malloc: %s\n", strerror(errno));
 		exit(EXIT_FAILURE);
-	}
 
 	for (i = 0; i < len; ++i) {
 		/* Note: really should test for -1 return from wctomb */
@@ -109,7 +107,7 @@ complete(EditLine *el, int __attribute__((unused)) ch)
 
 
 int
-main(int  __attribute__((unused)) argc, char *argv[])
+main(int argc, char *argv[])
 {
 	EditLine *el = NULL;
 	int numc, ncontinuation;
